preprocessings = {
    'county': {
        'census_full': {
            'lambdas': {
                'State': lambda x: state_abbreviations[x],
                'County': lambda x: x[:-7]
            },
            'rename': {
                'State': 'state',
                'County': 'county',
                'TotalPop': 'total_population',
                'Men': 'number_of_men',
                'Women': 'number_of_women',
                'Hispanic': 'race_hispanic',
                'White': 'race_white',
                'Black': 'race_black',
                'Native': 'race_native',
                'Asian': 'race_asian',
                'Pacific': 'pacific',
                'VotingAgeCitizen': 'voting_age_citizens',
                'Income': 'census_income_average',
                'IncomeErr': 'census_income_margin',
                'IncomePerCap': 'census_income_per_capita',
                'IncomePerCapErr': 'census_income_per_capita_margin',
                'Poverty': 'census_poverty',
                'ChildPoverty': 'census_child_poverty',
                'Professional': 'professional_job_percentage',
                'Service': 'service_job_percentage',
                'Office': 'office_job_percentage',
                'Construction': 'construction_job_percentage',
                'Production': 'production_job_percentage',
                'Drive': 'commute_drive_percentage',
                'Carpool': 'commute_carpool_percentage',
                'Transit': 'commute_transit_percentage',
                'Walk': 'commute_walk_percentage',
                'OtherTransp': 'commute_other_percentage',
                'WorkAtHome': 'commute_noneed_percentage',
                'Employed': 'number_of_employed_people',
                'PrivateWork': 'employment_private_percentage',
                'PublicWork': 'employment_public_percentage',
                'SelfEmployed': 'employment_self_percentage',
                'FamilyWork': 'employment_family_percentage',
                'Unemployment': 'unemployment_percentage'
            },
            'remove': ['MeanCommute', 'CountyId']
        },
        'diversityindex': {
            'lambdas': {
            },
            'rename': {
                'Diversity-Index': 'diversity_index',
                'Black or African American alone, percent, 2013': 'diversity_black_race',
                'American Indian and Alaska Native alone, percent, 2013': 'diversity_native_race',
                'Asian alone, percent, 2013': 'diversity_asian_race',
                'Native Hawaiian and Other Pacific Islander alone, percent,': 'diversity_pacific_race',
                'Two or More Races, percent, 2013': 'diversity_two_or_more_races',
                'Hispanic or Latino, percent, 2013': 'diversity_hispanic_race',
                'White alone, not Hispanic or Latino, percent, 2013': 'diversity_white_race'
            },
            'remove': []
        },
        'mortality': {
            'lambdas': {
            },
            'rename': {'Location': 'county'},
            'remove': ['FIPS']
        },
        'election': {
            'lambdas': {},
            'rename': {},
            'remove': ['FIPS'],
        },
        'icu_beds': {
            'lambdas': {},
            'rename': {'County': 'county', 'State': 'state', 'ICU Beds': 'icu_beds', 'Percent of Population Aged 60+': 'senior_population_percentage', 'Residents Aged 60+ Per Each ICU Bed': 'seniors_per_icubed'},
            'remove': ['Total Population', 'Population Aged 60+'],
        },
        'land_and_water': {
            'lambdas': {'NAME': lambda x: x[:-7] if x.endswith('County') else x},
            'rename': {'USPS': 'state', 'NAME': 'county'},
            'remove': ['GEOID', 'ANSICODE'],
        },
        'cases': {
            'lambdas': {},
            'rename': {'county_name': 'county', 'state_name': 'state'},
            'remove': []
        }

    }
}

state_abbreviations = {'Armed Forces (the) Americas': 'AA',
                       'Alberta': 'AB',
                       'Armed Forces Europe': 'AE',
                       'Alaska': 'AK',
                       'Alabama': 'AL',
                       'Armed Forces Pacific': 'AP',
                       'Arkansas': 'AR',
                       'American Samoa': 'AS',
                       'Arizona': 'AZ',
                       'British Columbia': 'BC',
                       'California': 'CA',
                       'Canada': 'CD',
                       'Colorado': 'CO',
                       'Connecticut': 'CT',
                       'Dist. Of Columbia': 'DC',
                       'Delaware': 'DE',
                       'Foreign Countries': 'FF',
                       'Florida': 'FL',
                       'Georgia': 'GA',
                       'Guam': 'GU',
                       'Hawaii': 'HI',
                       'Iowa': 'IA',
                       'Idaho': 'ID',
                       'Illinois': 'IL',
                       'Indiana': 'IN',
                       'Kansas': 'KS',
                       'Kentucky': 'KY',
                       'Louisiana': 'LA',
                       'Massachusetts': 'MA',
                       'Manitoba': 'MB',
                       'Maryland': 'MD',
                       'Maine': 'ME',
                       'Michigan': 'MI',
                       'Minnesota': 'MN',
                       'Missouri': 'MO',
                       'Mississippi': 'MS',
                       'Montana': 'MT',
                       'Mexico': 'MX',
                       'New Brunswick': 'NB',
                       'North Carolina': 'NC',
                       'North Dakota': 'ND',
                       'Nebraska': 'NE',
                       'New Hampshire': 'NH',
                       'New Jersey': 'NJ',
                       'Newfoundland and Labrador': 'NL',
                       'New Mexico': 'NM',
                       'Nova Scotia': 'NS',
                       'Northwest Territories': 'NT',
                       'Nunavut': 'NU',
                       'Nevada': 'NV',
                       'New York': 'NY',
                       'Ohio': 'OH',
                       'Oklahoma': 'OK',
                       'Ontario': 'ON',
                       'Oregon': 'OR',
                       'Pennsylvania': 'PA',
                       'Prince Edward Island': 'PE',
                       'Puerto Rico': 'PR',
                       'Quebec': 'QC',
                       'Rhode Island': 'RI',
                       'South Carolina': 'SC',
                       'South Dakota': 'SD',
                       'Saskatchewan': 'SK',
                       'Tennessee': 'TN',
                       'Trust Territory': 'TT',
                       'Texas': 'TX',
                       'Unknown': 'UN',
                       'Utah': 'UT',
                       'Virginia': 'VA',
                       'Virgin Islands': 'VI',
                       'Vermont': 'VT',
                       'Washington': 'WA',
                       'Wisconsin': 'WI',
                       'West Virginia': 'WV',
                       'Wyoming': 'WY',
                       'Yukon': 'YT',
                       'District of Columbia': "District of Columbia"
                       }

label2description = {
    'county': 'US County',
    'state': 'US State',
    'min_confirmed_count': 'COVID-19 - Minimum Confirmed COVID-19 Cases',
    'min_death_count': 'COVID-19 - Minimum COVID-19 Death Counts',
    'max_confirmed_count': 'COVID-19 - Maximum Confirmed COVID-19 Cases',
    'max_death_count': 'COVID-19 - Maximum COVID-19 Death Counts',
    'median_confirmed_count': 'COVID-19 - Median of Confirmed COVID-19 Cases',
    'median_death_count': 'COVID-19 - Median COVID-19 Death Counts',
    'mean_confirmed_count': 'COVID-19 - Mean of Confirmed COVID-19 Cases',
    'mean_death_count': 'COVID-19 - Mean of COVID-19 Death Counts',
    'sum_confirmed_count': 'COVID-19 - Sum of Confirmed COVID-19 Cases',
    'sum_death_count': 'COVID-19 - um of COVID-19 Death Counts',
    'total_population': 'County Population - Total Population',
    'number_of_men': 'County Population - Number of Men in the County',
    'number_of_women': 'County Population - Number of Women in the County',
    'men_percentage': 'County Population - Percentage of Men in the County',
    'women_percentage': 'County Population - Percentage of Women in the County',
    'race_hispanic': 'County Race - Hispanic Race Ratio',
    'race_white': 'County Race - White Race Ratio',
    'race_black': 'County Race - Black Race Ratio',
    'race_native': 'County Race - Native American Race Ratio',
    'race_asian': 'County Race - Asian Race Ratio',
    'pacific': 'County Race - Pacific Islander Race Ratio',
    'voting_age_citizens': 'Election - Number of Voting-age Citizens in the County',
    'normalized_voting_age_citizens': "Election - Number of Voting-age Citizens Normalized by the County Population",
    'census_income_average': 'County Economy - Average Income - Based on US Census',
    'census_income_margin': 'County Economy - Income Margin - Based on US Census',
    'census_income_per_capita': 'County Economy - Average Income per Capita - Based on US Census',
    'census_income_per_capita_margin': 'County Economy - Income per Capita Margin - Based on US Census',
    'census_poverty': 'County Economy - Poverty',
    'census_child_poverty': 'County Economy - Child Poverty',
    'professional_job_percentage': 'County Employment - Professional Job Percentage',
    'service_job_percentage': 'County Employment - Service Job Percentage',
    'office_job_percentage': 'County Employment - Office Job Percentage',
    'construction_job_percentage': 'County Employment - Construction Job Percentage',
    'production_job_percentage': 'County Employment - Production Job Percentage',
    'commute_drive_percentage': 'Commute to Work - Drive (Percentage)',
    'commute_carpool_percentage': 'Commute to Work - Carpool (Percentage)',
    'commute_transit_percentage': 'Commute to Work - Transit (Percentage)',
    'commute_walk_percentage': 'Commute to Work - Walk (Percentage)',
    'commute_other_percentage': 'Commute to Work - Other (Percentage)',
    'commute_noneed_percentage': 'Commute to Work - Work at Home (Percentage)',
    'number_of_employed_people': 'Commute to Work - Driving (Percentage)',
    'employment_private_percentage': 'Employment - Private Employment',
    'employment_public_percentage': 'Employment - Public Employment Percentage',
    'employment_self_percentage': 'Employment - Self Employment Percentage',
    'employment_family_percentage': 'Employment - Family Employment Percentage',
    'unemployment_percentage': 'Employment - Unemployment Percentage',
    'icu_beds': 'ICU - Number of ICU Beds',
    #'Total Population': 'Cou',
    'seniors_population_percentage': 'County Population - Seniors (above 60 years old) percentage',
    'seniors_per_icubed': 'ICU - Senior (above 60 years old) per each ICU bed',
    'diversity_index': 'Diversity - Diversity Index',
    'diversity_black_race': 'Diversity - Black Race Ratio',
    'diversity_native_race': 'Diversity - Native Race Ratio',
    'diversity_asian_race': 'Diversity - Asian Race Ratio',
    'diversity_pacific_race': 'Diversity - Pacific Islander Race Ratio',
    'diversity_two_or_more_races': 'Diversity - Two or More Race Combined Ratio',
    'diversity_hispanic_race': 'Diversity - Hispanic Race Ratio',
    'diversity_white_race': 'Diversity - White Race Ratio',
    'democrat': 'Election - Number of Democrat Votes',
    'republican': 'Election - Number of Republican Votes',
    'other': 'Election - Number of votes other than Democrat/Republican',
    'ALAND': 'Land and Water - Land Area',
    'AWATER': 'Land and Water - Water Area',
    'ALAND_SQMI': 'Land and Water - Land Area in Square Miles',
    'AWATER_SQMI': 'Land and Water - Water Area in Square Miles',
    # 'min_land_area': 'Minimum Land Area',
    # 'min_land_water': 'Minimum Water Area',
    # 'min_income_mean': 'Minimum Income Mean',
    # 'min_income_median': 'Minimum Income Median',
    # 'min_income_std': 'Minimum Income Deviation',
    # 'max_land_area': 'Maximum Land Area',
    # 'max_land_water': 'Maximum Water Area',
    # 'max_income_mean': 'Maximum Average Income',
    # 'max_income_median': 'Maximum Median Income',
    # 'max_income_std': 'Maximum Income Deviation',
    # 'median_land_area': 'Median Land Area',
    # 'median_land_water': 'Median Water Area',
    # 'median_income_mean': 'Median Average Income',
    # 'median_income_median': 'Median Median Income',
    # 'median_income_std': 'Median Income Deviation',
    # 'mean_land_area': 'Average Land Area',
    # 'mean_land_water': 'Average Water Area',
    # 'mean_income_mean': 'Average of Average Income',
    # 'mean_income_median': 'Average of Median Income',
    # 'mean_income_std': 'Average',
    # 'sum_land_area': 'Sum of Land Area',
    # 'sum_land_water': 'Sum of Water Area',
    # 'sum_income_mean': 'Sum of Average Income',
    # 'sum_income_median': 'Sum of Median Income',
    # 'sum_income_std': 'Sum of Income Deviation',
    'mortality_rate': 'Mortality - Mortality Rate',
    'min_mortality_rate': 'Mortality - Minimum Mortality Rate',
    'max_mortality_rate': 'Mortality - Maximum Mortality Rate',
    'change_in_mortality_rate': 'Mortality - Change in Mortality Rate',
    'min_change_in_mortality_rate': 'Mortality - Minimum Change in Mortality Rate',
    'max_change_in_mortality_rate': 'Mortality - Maximum Change in Mortality Rate',
    'location': 'County - State',
    'democrat_percentage': 'Election - Democrat Vote Percentage',
    'republican_percentage': 'Election - Republican Vote Percentage',
    'other_than_democrat_or_republican_percentage': 'Election - Votes other than democrat/republican - Percentage',
    'population_density': 'County Population - Population Density',
    'death_count_cumsum': 'COVID-19 - Cummulative Sum of COVID-19 Deaths',
    'confirmed_count_cumsum': 'COVID-19 - Cummulative Sum of Confirmed COVID-19 Cases',
    'recovered_count_cumsum': 'COVID-19 - Cummulative Sum of COVID-19 Recoveries',
    'normalized_death_count_cumsum': 'COVID-19 - Population Normalized Death Count Cumsum per region',
    'normalized_confirmed_count_cumsum': 'COVID-19 - Population Normalized Case Count Cumsum per region',
    'normalized_recovered_count_cumsum': 'COVID-19 - Population Recoveries Case Count Cumsum per region',
    'compliance': 'Mobility - Compliance with the Shelter at Home Criteria',
    'state_cumulative_covid_hospitalization_rate_per_100k_ag0_4': 'CDC Data - State Cumulative Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: 0-4',
    'state_cumulative_covid_hospitalization_rate_per_100k_ag18_49': 'CDC Data - State Cumulative Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: 18-49',
    'state_cumulative_covid_hospitalization_rate_per_100k_ag5_17': 'CDC Data - State Cumulative Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: 5-17',
    'state_cumulative_covid_hospitalization_rate_per_100k_ag50_64': 'CDC Data - State Cumulative Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: 50-64',
    'state_cumulative_covid_hospitalization_rate_per_100k_ag65p': 'CDC Data - State Cumulative Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: 65+',
    'state_cumulative_covid_hospitalization_rate_per_100k_ag65_74': 'CDC Data - State Cumulative Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: 65-74',
    'state_cumulative_covid_hospitalization_rate_per_100k_ag75_84': 'CDC Data - State Cumulative Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: 75-84',
    'state_cumulative_covid_hospitalization_rate_per_100k_ag85p': 'CDC Data - State Cumulative Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: 85+',
    'state_cumulative_covid_hospitalization_rate_per_100k_agoverall': 'CDC Data - State Cumulative Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: Overall',
    'state_weekly_covid_hospitalization_rate_per_100k_ag0_4': 'CDC Data - State Weekly Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: 0-4',
    'state_weekly_covid_hospitalization_rate_per_100k_ag18_49': 'CDC Data - State Weekly Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: 18-49',
    'state_weekly_covid_hospitalization_rate_per_100k_ag5_17': 'CDC Data - State Weekly Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: 5-17',
    'state_weekly_covid_hospitalization_rate_per_100k_ag50_64': 'CDC Data - State Weekly Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: 50-64',
    'state_weekly_covid_hospitalization_rate_per_100k_ag65p': 'CDC Data - State Weekly Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: 65+',
    'state_weekly_covid_hospitalization_rate_per_100k_ag65_74': 'CDC Data - State Weekly Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: 65-74',
    'state_weekly_covid_hospitalization_rate_per_100k_ag75_84': 'CDC Data - State Weekly Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: 75-84',
    'state_weekly_covid_hospitalization_rate_per_100k_ag85p': 'CDC Data - State Weekly Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: 85+',
    'state_weekly_covid_hospitalization_rate_per_100k_agoverall': 'CDC Data - State Weekly Lab Confirmed COVID-19 Hospitalization per 100,000 people - Age: Overall',
    'state_infleunza_activity_level': 'CDC Data - State Reported Influenza Activity Level - Surveys',
    'state_eating_and_drinking_locations': 'State Food Business - Number of Eating/Drinking Locations in the State',
    'state_restaurant_worker_population': 'State Food Business - Number of Restaurant Workers in the State',
    'state_restaurant_employment_percentage': 'State Food Business - Percentage of Restaurant Work in State Employment',
    'state_restaurants_annual_sale': 'State Food Business - State Annual Restaurant Sale',
    'restaurants_table_service_to_state_contribution': 'State Food Business - Contribution to State Economy from Every Dollar Spent on Restaurant - Table Services',
    'restaurants_limited_service_to_state_contribution': 'State Food Business - Contribution to State Economy from Every Dollar Spent on Restaurant - Limited Services',
    'google_mobility_retail_and_recreation_percent_change_from_baseline': 'Mobility - Changes From Baseline - Retail and Recreation',
    'google_mobility_grocery_and_pharmacy_percent_change_from_baseline': 'Mobility - Changes From Baseline - Grocery and Pharmacy',
    'google_mobility_parks_percent_change_from_baseline': 'Mobility - Changes From Baseline - Parks',
    'google_mobility_transit_stations_percent_change_from_baseline': 'Mobility - Changes From Baseline - Transit Stations',
    'google_mobility_workplaces_percent_change_from_baseline': 'Mobility - Changes From Baseline - Workplaces',
    'google_mobility_residential_percent_change_from_baseline': 'Mobility - Changes From Baseline - Residential',
    'confirmed_count_cumsum_per100k': 'COVID-19 - Cumulative Confirmed COVID-19 Cases per 100,000 People in the County',
    'death_count_cumsum_per100k': 'COVID-19 - Cumulative Deaths due to COVID-19 per 100,000 People in the County',
    'recovered_count_cumsum_per100k': 'COVID-19 - Cumulative Recoveries from COVID-19 per 100,000 People in the County'
}

plot_domains = {
    'x_or_color': [
        'total_population',
        'number_of_men',
        'number_of_women',
        'race_hispanic',
        'race_white',
        'race_black',
        'race_native',
        'race_asian',
        'pacific',
        'voting_age_citizens',
        'census_income_average',
        'census_income_margin',
        'census_income_per_capita',
        'census_income_per_capita_margin',
        'census_poverty',
        'census_child_poverty',
        'professional_job_percentage',
        'service_job_percentage',
        'office_job_percentage',
        'construction_job_percentage',
        'production_job_percentage',
        'commute_drive_percentage',
        'commute_carpool_percentage',
        'commute_transit_percentage',
        'commute_walk_percentage',
        'commute_other_percentage',
        'commute_noneed_percentage',
        'number_of_employed_people',
        'employment_private_percentage',
        'employment_public_percentage',
        'employment_self_percentage',
        'employment_family_percentage',
        'unemployment_percentage',
        'icu_beds',
        'Total Population',
        'Population Aged 60+',
        'Percent of Population Aged 60+',
        'Residents Aged 60+ Per Each ICU Bed',
        'diversity_index',
        'diversity_black_race',
        'diversity_native_race',
        'diversity_asian_race',
        'diversity_pacific_race',
        'diversity_two_or_more_races',
        'diversity_hispanic_race',
        'diversity_white_race',
        'democrat',
        'republican',
        'other',
        'ALAND',
        'AWATER',
        'ALAND_SQMI',
        'AWATER_SQMI',
        'min_land_area',
        'min_land_water',
        'min_income_mean',
        'min_income_median',
        'min_income_std',
        'max_land_area',
        'max_land_water',
        'max_income_mean',
        'max_income_median',
        'max_income_std',
        'median_land_area',
        'median_land_water',
        'median_income_mean',
        'median_income_median',
        'median_income_std',
        'mean_land_area',
        'mean_land_water',
        'mean_income_mean',
        'mean_income_median',
        'mean_income_std',
        'sum_land_area',
        'sum_land_water',
        'sum_income_mean',
        'sum_income_median',
        'sum_income_std',
        'mortality_rate',
        'min_mortality_rate',
        'max_mortality_rate',
        'change_in_mortality_rate',
        'min_change_in_mortality_rate',
        'max_change_in_mortality_rate',
        'democrat_percentage',
        'republican_percentage',
        'other_than_democrat_or_republican_percentage',
        'population_density',
        'Republican Vote Percentage'
    ],
    'y': ['min_confirmed_count',
          'min_death_count',
          'max_confirmed_count',
          'max_death_count',
          'median_confirmed_count',
          'median_death_count',
          'mean_confirmed_count',
          'mean_death_count',
          'sum_confirmed_count',
          'sum_death_count']
}

main_plot_domain = {
    'x_or_color': [
        'total_population',
        'number_of_men',
        'number_of_women',
        'race_hispanic',
        'race_white',
        'race_black',
        'race_native',
        'race_asian',
        'pacific',
        'voting_age_citizens',
        'census_income_average',
        'census_income_margin',
        'census_income_per_capita',
        'census_income_per_capita_margin',
        'census_poverty',
        'census_child_poverty',
        'professional_job_percentage',
        'service_job_percentage',
        'office_job_percentage',
        'construction_job_percentage',
        'production_job_percentage',
        'commute_drive_percentage',
        'commute_carpool_percentage',
        'commute_transit_percentage',
        'commute_walk_percentage',
        'commute_other_percentage',
        'commute_noneed_percentage',
        'number_of_employed_people',
        'employment_private_percentage',
        'employment_public_percentage',
        'employment_self_percentage',
        'employment_family_percentage',
        'unemployment_percentage',
        'icu_beds',
        'Total Population',
        'Population Aged 60+',
        'Percent of Population Aged 60+',
        'Residents Aged 60+ Per Each ICU Bed',
        'diversity_index',
        'diversity_black_race',
        'diversity_native_race',
        'diversity_asian_race',
        'diversity_pacific_race',
        'diversity_two_or_more_races',
        'diversity_hispanic_race',
        'diversity_white_race',
        'ALAND_SQMI',
        'AWATER_SQMI',
        'mean_land_area',
        'mean_land_water',
        'mean_income_mean',
        'mean_income_median',
        'mean_income_std',
        'mortality_rate',
        'min_mortality_rate',
        'max_mortality_rate',
        'change_in_mortality_rate',
        'min_change_in_mortality_rate',
        'max_change_in_mortality_rate',
        'democrat_percentage',
        'republican_percentage',
        'other_than_democrat_or_republican_percentage',
        'population_density'
    ],
    'y': [
        'max_death_count',
        'max_confirmed_count']
}

feature_categories = {
    'food_business': [
        'state_eating_and_drinking_locations',
        'state_restaurant_worker_population',
        'state_restaurant_employment_percentage',
        'state_restaurants_annual_sale',
        'restaurants_table_service_to_state_contribution',
        'restaurants_limited_service_to_state_contribution',
    ],
    'gender': [
        'total_population',
        'number_of_men',
        'number_of_women',
        'men_percentage',
        'women_percentage',
        'population_density'
    ],
    'race': [
        'race_hispanic',
        'race_white',
        'race_black',
        'race_native',
        'race_asian',
        'pacific',
    ],
    'election' :[
        'voting_age_citizens',
        'normalized_voting_age_citizens',
        'democrat',
        'republican',
        'other',
        'democrat_percentage',
        'republican_percentage',
        'other_than_democrat_or_republican_percentage',
    ],
    'income_and_poverty': [
        'census_income_average',
        'census_income_margin',
        'census_income_per_capita',
        'census_income_per_capita_margin',
        'census_poverty',
        'census_child_poverty',
    ],
    'commute_to_work': [
        'commute_drive_percentage',
        'commute_carpool_percentage',
        'commute_transit_percentage',
        'commute_walk_percentage',
        'commute_other_percentage',
        'commute_noneed_percentage',
    ],
    'hospitals_and_mortality': [
        'icu_beds',
        'Residents Aged 60+ Per Each ICU Bed',
        'mortality_rate',
        'min_mortality_rate',
        'max_mortality_rate',
        'change_in_mortality_rate',
        'min_change_in_mortality_rate',
        'max_change_in_mortality_rate',
    ],
    'land_and_water': [
        'ALAND',
        'AWATER',
        'ALAND_SQMI',
    ],
    'old_age': [
        'Population Aged 60+',
        'Percent of Population Aged 60+',
    ]
}

dynamic_features = [
            'compliance',
            'google_mobility_retail_and_recreation_percent_change_from_baseline',
            'google_mobility_grocery_and_pharmacy_percent_change_from_baseline',
            'google_mobility_parks_percent_change_from_baseline',
            'google_mobility_transit_stations_percent_change_from_baseline',
            'google_mobility_workplaces_percent_change_from_baseline',
            'google_mobility_residential_percent_change_from_baseline',
            'state_cumulative_covid_hospitalization_rate_per_100k_ag0_4',
            'state_weekly_covid_hospitalization_rate_per_100k_ag0_4',
            'state_cumulative_covid_hospitalization_rate_per_100k_ag18_49',
            'state_weekly_covid_hospitalization_rate_per_100k_ag18_49',
            'state_cumulative_covid_hospitalization_rate_per_100k_ag5_17',
            'state_weekly_covid_hospitalization_rate_per_100k_ag5_17',
            'state_cumulative_covid_hospitalization_rate_per_100k_ag50_64',
            'state_weekly_covid_hospitalization_rate_per_100k_ag50_64',
            'state_cumulative_covid_hospitalization_rate_per_100k_ag65p',
            'state_weekly_covid_hospitalization_rate_per_100k_ag65p',
            'state_cumulative_covid_hospitalization_rate_per_100k_ag65_74',
            'state_weekly_covid_hospitalization_rate_per_100k_ag65_74',
            'state_cumulative_covid_hospitalization_rate_per_100k_ag75_84',
            'state_weekly_covid_hospitalization_rate_per_100k_ag75_84',
            'state_cumulative_covid_hospitalization_rate_per_100k_ag85p',
            'state_weekly_covid_hospitalization_rate_per_100k_ag85p',
            'state_cumulative_covid_hospitalization_rate_per_100k_agoverall',
            'state_weekly_covid_hospitalization_rate_per_100k_agoverall',
            'state_infleunza_activity_level',
        ]
target_features = [
            'min_confirmed_count',
            'min_death_count',
            'min_recovered_count',
            'max_confirmed_count',
            'max_death_count',
            'max_recovered_count',
            'median_confirmed_count',
            'median_death_count',
            'median_recovered_count',
            'mean_confirmed_count',
            'mean_death_count',
            'mean_recovered_count',
            'sum_confirmed_count',
            'sum_death_count',
            'sum_recovered_count',
            'confirmed_count',
            'death_count',
            'recovered_count',
            'death_count_cumsum',
            'confirmed_count_cumsum',
            'recovered_count_cumsum',
            'normalized_confirmed_count_cumsum',
            'normalized_death_count_cumsum',
            'normalized_recovered_count_cumsum',
            'confirmed_count_cumsum_per100k',
            'death_count_cumsum_per100k',
            'recovered_count_cumsum_per100k'
        ]
static_features=[
            'state_eating_and_drinking_locations',
            'state_restaurant_worker_population',
            'state_restaurant_employment_percentage',
            'state_restaurants_annual_sale',
            'restaurants_table_service_to_state_contribution',
            'restaurants_limited_service_to_state_contribution',
            'total_population',
            'number_of_men',
            'number_of_women',
            'men_percentage',
            'women_percentage',
            'race_hispanic',
            'race_white',
            'race_black',
            'race_native',
            'race_asian',
            'pacific',
            'voting_age_citizens',
            'normalized_voting_age_citizens',
            'census_income_average',
            'census_income_margin',
            'census_income_per_capita',
            'census_income_per_capita_margin',
            'census_poverty',
            'census_child_poverty',
            'professional_job_percentage',
            'service_job_percentage',
            'office_job_percentage',
            'construction_job_percentage',
            'production_job_percentage',
            'commute_drive_percentage',
            'commute_carpool_percentage',
            'commute_transit_percentage',
            'commute_walk_percentage',
            'commute_other_percentage',
            'commute_noneed_percentage',
            'number_of_employed_people',
            'employment_private_percentage',
            'employment_public_percentage',
            'employment_self_percentage',
            'employment_family_percentage',
            'unemployment_percentage',
            'icu_beds',
            'Population Aged 60+',
            'Percent of Population Aged 60+',
            'Residents Aged 60+ Per Each ICU Bed',
            'diversity_index',
            'diversity_black_race',
            'diversity_native_race',
            'diversity_asian_race',
            'diversity_pacific_race',
            'diversity_two_or_more_races',
            'diversity_hispanic_race',
            'diversity_white_race',
            'democrat',
            'republican',
            'other',
            'democrat_percentage',
            'republican_percentage',
            'other_than_democrat_or_republican_percentage',
            'ALAND',
            'AWATER',
            'ALAND_SQMI',
            'AWATER_SQMI',
            'mortality_rate',
            'min_mortality_rate',
            'max_mortality_rate',
            'change_in_mortality_rate',
            'min_change_in_mortality_rate',
            'max_change_in_mortality_rate',
            'population_density'
        ]
